===============================
Plushcap
===============================

.. image:: https://badge.fury.io/py/plushcap.png
    :target: http://badge.fury.io/py/plushcap

.. image:: https://travis-ci.org/mickstevens/plushcap.png?branch=master
        :target: https://travis-ci.org/mickstevens/plushcap

.. image:: https://pypip.in/d/plushcap/badge.png
        :target: https://pypi.python.org/pypi/plushcap


Plushcap monitors websites and alerts people via text or phone call if there is a problem.

* Free software: BSD license
* Documentation: https://plushcap.readthedocs.org.

Features
--------

* TODO